@@ -204,27 +204,30 @@ on_dbus_signal_received (GDBusConnection *connection,
   ZeitgeistDataSource                *src;
   gchar                              *unique_id;
   gboolean                            enabled;
+  GVariant                           *vsrc;
 
   self = ZEITGEIST_DATA_SOURCE_REGISTRY (user_data);
   priv = ZEITGEIST_DATA_SOURCE_REGISTRY_GET_PRIVATE (self);
 
   if (g_strcmp0 (signal_name, "DataSourceRegistered") == 0)
     {
-      src = zeitgeist_data_source_new_from_variant (g_variant_get_child_value (parameters, 0)); // FIXME: ref?
-      g_signal_emit (self, _registry_signals[SOURCE_REGISTERED],
-                     0, src);
+      vsrc = g_variant_get_child_value (parameters, 0);
+      src = zeitgeist_data_source_new_from_variant (vsrc);
+      g_signal_emit (self, _registry_signals[SOURCE_REGISTERED], 0, src);
+      g_variant_unref (vsrc);
       g_object_unref (src);
     }
   else if (g_strcmp0 (signal_name, "DataSourceDisconnected") == 0)
     {
-      src = zeitgeist_data_source_new_from_variant (g_variant_get_child_value (parameters, 0)); // FIXME: ref?
-      g_signal_emit (self, _registry_signals[SOURCE_DISCONNECTED],
-                     0, src);
+      vsrc = g_variant_get_child_value (parameters, 0);
+      src = zeitgeist_data_source_new_from_variant (vsrc);
+      g_signal_emit (self, _registry_signals[SOURCE_DISCONNECTED], 0, src);
+      g_variant_unref (vsrc);
       g_object_unref (src);
     }
   else if (g_strcmp0 (signal_name, "DataSourceEnabled") == 0)
     {
-      g_variant_get (parameters, "sb", &unique_id, &enabled); // FIXME: unref?
+      g_variant_get (parameters, "(sb)", &unique_id, &enabled); // FIXME: unref?
       g_signal_emit (self, _registry_signals[SOURCE_ENABLED],
           0, unique_id, enabled);
       g_free (unique_id);
@@ -363,7 +366,10 @@ zeitgeist_data_source_registry_get_data_sources_finish (
   vsources = g_variant_get_child_value (val, 0);
   g_variant_unref (val);
 
-  return zeitgeist_data_sources_from_variant (vsources); // owns ref
+  sources = zeitgeist_data_sources_from_variant (vsources);
+  g_variant_unref (vsources);
+
+  return sources;
 }
 
 /**
