@@ -145,7 +145,8 @@ zeitgeist_data_source_new_from_variant (GVariant *src)
                  NULL, &running, &timestamp, &enabled);
 
   event_templates_data = g_variant_get_child_value (src, 3);
-  event_templates = zeitgeist_events_from_variant (event_templates_data); //own ref
+  event_templates = zeitgeist_events_from_variant (event_templates_data);
+  g_variant_unref (event_templates_data);
 
   /* Build the ZeitgeistDataSource */
   result = zeitgeist_data_source_new_full (unique_id, name, description,
@@ -569,7 +570,8 @@ zeitgeist_data_sources_from_variant  (GVariant *sources)
   for (i = 0; i < n_sources; i++)
     {
       vsrc = g_variant_get_child_value (sources, i);
-      src = zeitgeist_data_source_new_from_variant (vsrc); // vsrc freed
+      src = zeitgeist_data_source_new_from_variant (vsrc);
+      g_variant_unref (vsrc);
       g_ptr_array_add (result, src);
     }
 
