@@ -63,6 +63,14 @@ G_BEGIN_DECLS
  * @ZEITGEIST_RESULT_TYPE_LEAST_RECENT_MIMETYPE: One event for each mimetype only, ordered with the least recent events first
  * @ZEITGEIST_RESULT_TYPE_MOST_POPULAR_MIMETYPE: One event for each mimetype only, ordered by the popularity of the mimetype
  * @ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_MIMETYPE: One event for each mimetype only, ordered ascendingly by popularity of the mimetype
+ * @ZEITGEIST_RESULT_TYPE_MOST_RECENT_CURRENT_URI: One event for each current uri only, ordered with the most recent events first
+ * @ZEITGEIST_RESULT_TYPE_LEAST_RECENT_CURRENT_URI: One event for each current uri only, ordered with oldest events first
+ * @ZEITGEIST_RESULT_TYPE_MOST_POPULAR_CURRENT_URI: One event for each current uri only, ordered by the popularity of the current uri
+ * @ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_CURRENT_URI: One event for each current uri only, ordered ascendingly by popularity
+ * @ZEITGEIST_RESULT_TYPE_MOST_RECENT_EVENT_ORIGIN: One event for each event origin only, ordered with the most recent events first
+ * @ZEITGEIST_RESULT_TYPE_LEAST_RECENT_EVENT_ORIGIN: One event for each event origin only, ordered with the least recent events first
+ * @ZEITGEIST_RESULT_TYPE_MOST_POPULAR_EVENT_ORIGIN: One event for each event origin only, ordered by the popularity of the event origin
+ * @ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_EVENT_ORIGIN: One event for each event origin only, ordered ascendingly by popularity of the event origin
  * @ZEITGEIST_RESULT_TYPE_RELEVANCY: Only allowed on zeitgeist_index_search(). Events are sorted by query relevancy
  *
  * Used to control how the query results are grouped and sorted.
@@ -94,6 +102,14 @@ typedef enum
   ZEITGEIST_RESULT_TYPE_LEAST_RECENT_MIMETYPE = 20,
   ZEITGEIST_RESULT_TYPE_MOST_POPULAR_MIMETYPE = 21,
   ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_MIMETYPE = 22,
+  ZEITGEIST_RESULT_TYPE_MOST_RECENT_CURRENT_URI = 23,
+  ZEITGEIST_RESULT_TYPE_LEAST_RECENT_CURRENT_URI = 24,
+  ZEITGEIST_RESULT_TYPE_MOST_POPULAR_CURRENT_URI = 25,
+  ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_CURRENT_URI = 26,
+  ZEITGEIST_RESULT_TYPE_MOST_RECENT_EVENT_ORIGIN = 27,
+  ZEITGEIST_RESULT_TYPE_LEAST_RECENT_EVENT_ORIGIN = 28,
+  ZEITGEIST_RESULT_TYPE_MOST_POPULAR_EVENT_ORIGIN = 29,
+  ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_EVENT_ORIGIN = 30,
   ZEITGEIST_RESULT_TYPE_RELEVANCY = 100,
 } ZeitgeistResultType;
 
