@@ -35,6 +35,14 @@ zeitgeist_result_type_get_type (void)
         { ZEITGEIST_RESULT_TYPE_LEAST_RECENT_MIMETYPE, "ZEITGEIST_RESULT_TYPE_LEAST_RECENT_MIMETYPE", "least-recent-mimetype" },
         { ZEITGEIST_RESULT_TYPE_MOST_POPULAR_MIMETYPE, "ZEITGEIST_RESULT_TYPE_MOST_POPULAR_MIMETYPE", "most-popular-mimetype" },
         { ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_MIMETYPE, "ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_MIMETYPE", "least-popular-mimetype" },
+        { ZEITGEIST_RESULT_TYPE_MOST_RECENT_CURRENT_URI, "ZEITGEIST_RESULT_TYPE_MOST_RECENT_CURRENT_URI", "most-recent-current-uri" },
+        { ZEITGEIST_RESULT_TYPE_LEAST_RECENT_CURRENT_URI, "ZEITGEIST_RESULT_TYPE_LEAST_RECENT_CURRENT_URI", "least-recent-current-uri" },
+        { ZEITGEIST_RESULT_TYPE_MOST_POPULAR_CURRENT_URI, "ZEITGEIST_RESULT_TYPE_MOST_POPULAR_CURRENT_URI", "most-popular-current-uri" },
+        { ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_CURRENT_URI, "ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_CURRENT_URI", "least-popular-current-uri" },
+        { ZEITGEIST_RESULT_TYPE_MOST_RECENT_EVENT_ORIGIN, "ZEITGEIST_RESULT_TYPE_MOST_RECENT_EVENT_ORIGIN", "most-recent-event-origin" },
+        { ZEITGEIST_RESULT_TYPE_LEAST_RECENT_EVENT_ORIGIN, "ZEITGEIST_RESULT_TYPE_LEAST_RECENT_EVENT_ORIGIN", "least-recent-event-origin" },
+        { ZEITGEIST_RESULT_TYPE_MOST_POPULAR_EVENT_ORIGIN, "ZEITGEIST_RESULT_TYPE_MOST_POPULAR_EVENT_ORIGIN", "most-popular-event-origin" },
+        { ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_EVENT_ORIGIN, "ZEITGEIST_RESULT_TYPE_LEAST_POPULAR_EVENT_ORIGIN", "least-popular-event-origin" },
         { ZEITGEIST_RESULT_TYPE_RELEVANCY, "ZEITGEIST_RESULT_TYPE_RELEVANCY", "relevancy" },
         { 0, NULL, NULL }
       };
