@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Canonical, Ltd.
+ * Copyright (C) 2010-2012 Canonical, Ltd.
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -17,6 +17,7 @@
  *
  * Authored by
  *             Mikkel Kamstrup Erlandsen <mikkel.kamstrup@canonical.com>
+ *             Michal Hruby <michal.hruby@canonical.com>
  */
 
 #if HAVE_CONFIG_H
@@ -254,7 +255,7 @@ zeitgeist_index_new (void)
  *                   templates
  * @offset: Offset into the result set to read events from
  * @num_events: Maximal number of events to retrieve
- * @result_type: The #ZeitgeistResultType  determining the sort order.
+ * @result_type: The #ZeitgeistResultType determining the sort order.
  *               You may pass #ZEITGEIST_RESULT_TYPE_RELEVANCY to this method
  *               to have the results ordered by relevancy calculated in relation
  *               to @query
@@ -348,10 +349,11 @@ zeitgeist_index_search (ZeitgeistIndex      *self,
  * Retrieve the result from an asynchronous query started with
  * zeitgeist_index_search().
  *
- * The total hit count of the query will be avilable via the returned
+ * The total hit count of the query will be available via the returned
  * result set by calling zeitgeist_result_set_estimated_matches(). This will
- * often be bigger than actual number of events held in the result set, which
- * is limited by the @num_events paramter passed to zeitgeist_index_search().
+ * often be bigger than the actual number of events held in the result set,
+ * which is limited by the @num_events parameter passed to
+ * zeitgeist_index_search().
  *
  * Returns: A newly allocated #ZeitgeistResultSet containing the
  *          #ZeitgeistEvent<!-- -->s matching the query. You must free the
@@ -389,6 +391,169 @@ zeitgeist_index_search_finish (ZeitgeistIndex      *self,
   return _zeitgeist_simple_result_set_new (events, num_hits);
 }
 
+/**
+ * zeitgeist_index_search_with_relevancies:
+ * @self: The #ZeitgeistIndex you want to query
+ * @query: The search string to send to Zeitgeist
+ * @time_range: Restrict matched events to ones within this time range. If you
+ *              are not interested in restricting the timerange pass
+ *              zeitgeist_time_range_new_anytime() as Zeitgeist will detect this
+ *              and optimize the query accordingly
+ * @event_templates: Restrict matched events to ones matching these
+ *                   templates
+ * @storage_state: Filter the events by availability of the storage medium.
+ * @offset: Offset into the result set to read events from
+ * @num_events: Maximal number of events to retrieve
+ * @result_type: The #ZeitgeistResultType determining the sort order.
+ *               You may pass #ZEITGEIST_RESULT_TYPE_RELEVANCY to this method
+ *               to have the results ordered by relevancy calculated in relation
+ *               to @query
+ * @cancellable: A #GCancellable used to cancel the call or %NULL
+ * @callback: A #GAsyncReadyCallback to invoke when the search results are ready
+ * @user_data: User data to pass back with @callback
+ *
+ * Perform a full text search possibly restricted to a #ZeitgeistTimeRange
+ * and/or set of event templates. As opposed to zeitgeist_index_search(), this
+ * call will also return numeric relevancies of the events
+ * in the #ZeitgeistResultSet.
+ *
+ * See zeitgeist_index_search() for more details on how to create the query.
+ */
+void
+zeitgeist_index_search_with_relevancies (ZeitgeistIndex       *self,
+                                         const gchar          *query,
+                                         ZeitgeistTimeRange   *time_range,
+                                         GPtrArray            *event_templates,
+                                         ZeitgeistStorageState storage_state,
+                                         guint32               offset,
+                                         guint32               num_events,
+                                         ZeitgeistResultType   result_type,
+                                         GCancellable         *cancellable,
+                                         GAsyncReadyCallback   callback,
+                                         gpointer              user_data)
+{
+  ZeitgeistIndexPrivate *priv;
+  GVariant              *vevents, *vtime_range, *params;
+  GVariantBuilder        b;
+  MethodDispatchContext *ctx;
+
+  g_return_if_fail (ZEITGEIST_IS_INDEX (self));
+  g_return_if_fail (query != NULL);
+  g_return_if_fail (ZEITGEIST_IS_TIME_RANGE (time_range));
+  g_return_if_fail (event_templates != NULL);
+  g_return_if_fail (cancellable == NULL || G_IS_CANCELLABLE(cancellable));
+
+  priv = ZEITGEIST_INDEX_GET_PRIVATE (self);
+
+  /* Own all floating refs on the events, and frees the events array */
+  vevents = zeitgeist_events_to_variant (event_templates);
+
+  /* Owns floating ref on time_range */
+  vtime_range = zeitgeist_time_range_to_variant (time_range);
+
+  /* Build the method params */
+  g_variant_builder_init (&b, G_VARIANT_TYPE ("(s(xx)a(asaasay)uuuu)"));
+  g_variant_builder_add (&b, "s", query);
+  g_variant_builder_add_value (&b, vtime_range); // owns ref
+  g_variant_builder_add_value (&b, vevents); // owns ref
+  g_variant_builder_add (&b, "u", storage_state);
+  g_variant_builder_add (&b, "u", offset);
+  g_variant_builder_add (&b, "u", num_events);
+  g_variant_builder_add (&b, "u", result_type);
+  params = g_variant_builder_end (&b);
+
+  ctx = g_new0 (MethodDispatchContext, 1);
+  ctx->self = g_object_ref (self);
+  ctx->method_name = "SearchWithRelevancies";
+  ctx->params = params;
+  ctx->cancellable = cancellable;
+  ctx->cb = callback;
+  ctx->user_data = user_data;
+
+  dispatch_method (ctx);
+}
+
+/**
+ * zeitgeist_index_search_with_relevancies_finish:
+ * @self: The #ZeitgeistIndex to retrieve results from
+ * @res: The #GAsyncResult you received in the #GAsyncReadyCallback you passed
+ *       to zeitgeist_index_search_with_relevancies()
+ * @relevancies: (out) (array): Location for the newly allocated array
+ *                              with relevancies.
+ * @relevancies_size: (out): Location for the size of the newly allocated array.
+ * @error: A place to store a #GError or %NULL in case you want to ignore errors
+ *
+ * Retrieve the result from an asynchronous query started with
+ * zeitgeist_index_search_with_relevancies().
+ *
+ * The total hit count of the query will be available via the returned
+ * result set by calling zeitgeist_result_set_estimated_matches(). This will
+ * often be bigger than the actual number of events held in the result set,
+ * which is limited by the @num_events parameter passed to
+ * zeitgeist_index_search_with_relevancies().
+ *
+ * Returns: A newly allocated #ZeitgeistResultSet containing the
+ *          #ZeitgeistEvent<!-- -->s matching the query. You must free the
+ *          result set with g_object_unref(). The events held in the result set
+ *          will automatically be unreffed when it is finalized.
+ */
+ZeitgeistResultSet*
+zeitgeist_index_search_with_relevancies_finish (ZeitgeistIndex *self,
+                                                GAsyncResult   *res,
+                                                gdouble       **relevancies,
+                                                gint           *relevancies_size,
+                                                GError        **error)
+{
+  ZeitgeistIndexPrivate *priv;
+  GPtrArray             *events;
+  guint32                num_hits;
+  GVariant              *val, *vevents, *vrelevancies, *vnum_hits;
+
+  g_return_val_if_fail (ZEITGEIST_IS_INDEX (self), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (res), NULL);
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+  priv = ZEITGEIST_INDEX_GET_PRIVATE (self);
+  val = g_dbus_proxy_call_finish (priv->index, res, error);
+
+  if (val == NULL)
+    return NULL;
+
+  /* Unpack return value from wrapper struct */
+  vevents = g_variant_get_child_value (val, 0);
+  vrelevancies = g_variant_get_child_value (val, 1);
+  vnum_hits = g_variant_get_child_value (val, 2);
+
+  events = zeitgeist_events_from_variant (vevents);
+  num_hits = g_variant_get_uint32 (vnum_hits);
+  if (relevancies_size)
+  {
+    *relevancies_size = g_variant_n_children (vrelevancies);
+  }
+  if (relevancies)
+  {
+    GVariantIter iter;
+    gdouble relevancy;
+    int i;
+
+    *relevancies = g_new (gdouble, g_variant_n_children (vrelevancies));
+
+    i = 0;
+    g_variant_iter_init (&iter, vrelevancies);
+    while (g_variant_iter_loop (&iter, "d", &relevancy))
+    {
+      (*relevancies)[i++] = relevancy;
+    }
+  }
+
+  g_variant_unref (val);
+  g_variant_unref (vevents);
+  g_variant_unref (vrelevancies);
+  g_variant_unref (vnum_hits);
+
+  return _zeitgeist_simple_result_set_new (events, num_hits);
+}
+
 static void
 on_proxy_acquired (GObject *source_object,
                    GAsyncResult *res,
