@@ -74,10 +74,31 @@ void            zeitgeist_index_search          (ZeitgeistIndex        *self,
                                                  gpointer               user_data);
 
 ZeitgeistResultSet*
-                zeitgeist_index_search_finish  (ZeitgeistIndex        *self,
+                zeitgeist_index_search_finish  (ZeitgeistIndex      *self,
                                                 GAsyncResult        *res,
                                                 GError             **error);
 
+void            zeitgeist_index_search_with_relevancies
+                                               (ZeitgeistIndex       *self,
+                                                const gchar          *query,
+                                                ZeitgeistTimeRange   *time_range,
+                                                GPtrArray            *event_templates,
+                                                ZeitgeistStorageState storage_state,
+                                                guint32               offset,
+                                                guint32               num_events,
+                                                ZeitgeistResultType   result_type,
+                                                GCancellable         *cancellable,
+                                                GAsyncReadyCallback   callback,
+                                                gpointer              user_data);
+
+ZeitgeistResultSet*
+                zeitgeist_index_search_with_relevancies_finish 
+                                               (ZeitgeistIndex      *self,
+                                                GAsyncResult        *res,
+                                                gdouble            **relevancies,
+                                                gint                *relevancies_size,
+                                                GError             **error);
+
 G_END_DECLS
 
 #endif /* _ZEITGEIST_INDEX_H_ */
