@@ -53,9 +53,6 @@ typedef struct
   /* Our connection to the bus */
   GDBusConnection *connection;
 
-  /* Handle for our bus watcher, looking out for the zg daemon */
-  guint watcher_id;
-
   /* The connection to the ZG daemon.
    * If log != NULL it means we have a connection */
   GDBusProxy *log;
@@ -94,11 +91,6 @@ typedef struct
   gpointer             user_data;
 } MethodDispatchContext;
 
-static void    _zeitgeist_log_on_zg_appeared    (GDBusConnection *connection,
-                                                 const gchar     *name,
-                                                 const gchar     *name_owner,
-                                                 gpointer         user_data);
-
 static void    _zeitgeist_log_on_name_owner_changed (GObject *proxy,
                                                      GParamSpec *pspec,
                                                      gpointer user_data);
@@ -137,13 +129,15 @@ zeitgeist_log_init (ZeitgeistLog *self)
   priv->monitors = g_hash_table_new (g_direct_hash, g_direct_equal);
 
   /* Set up the connection to the ZG daemon */
-  priv->watcher_id = g_bus_watch_name (G_BUS_TYPE_SESSION,
-                                       "org.gnome.zeitgeist.Engine",
-                                       G_BUS_NAME_WATCHER_FLAGS_AUTO_START,
-                                       _zeitgeist_log_on_zg_appeared,
-                                       NULL,
-                                       self,
-                                       NULL);
+  g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION,
+                            G_DBUS_PROXY_FLAGS_NONE,
+                            NULL,
+                            "org.gnome.zeitgeist.Engine",
+                            "/org/gnome/zeitgeist/log/activity",
+                            "org.gnome.zeitgeist.Log",
+                            NULL,
+                            _zeitgeist_log_on_zg_proxy_acquired,
+                            g_object_ref (self));
 }
 
 static void
@@ -160,12 +154,6 @@ zeitgeist_log_finalize (GObject *object)
       priv->connection = NULL;
     }
 
-  if (priv->watcher_id)
-    {
-      g_bus_unwatch_name (priv->watcher_id);
-      priv->watcher_id = 0;
-    }
-
   if (priv->log)
     {
       g_object_unref (priv->log);
@@ -1050,40 +1038,8 @@ zeitgeist_log_quit_finish (ZeitgeistLog        *self,
   return TRUE;
 }
 
-/* Called when the Zeitgeist daemon enters the bus */
-static void
-_zeitgeist_log_on_zg_appeared (GDBusConnection *connection,
-                               const gchar     *name,
-                               const gchar     *name_owner,
-                               gpointer         user_data)
-{
-  ZeitgeistLog        *self;
-  ZeitgeistLogPrivate *priv;
-
-  self = ZEITGEIST_LOG (user_data);
-  priv = ZEITGEIST_LOG_GET_PRIVATE (self);
-
-  if (priv->connection == NULL)
-    {
-      priv->connection = g_object_ref (connection);
-    }
-
-  if (priv->log == NULL)
-    {
-      g_dbus_proxy_new (connection,
-                        G_DBUS_PROXY_FLAGS_NONE,
-                        NULL,
-                        name,
-                        "/org/gnome/zeitgeist/log/activity",
-                        "org.gnome.zeitgeist.Log",
-                        NULL,
-                        _zeitgeist_log_on_zg_proxy_acquired,
-                        g_object_ref (self));
-    }
-}
-
 /* Async callback for when a proxy is ready
- * - triggered from _zeitgeist_log_on_zg_appeared */
+ * - triggered from zeitgeist_log_init */
 static void
 _zeitgeist_log_on_zg_proxy_acquired (GObject *source_object,
                                      GAsyncResult *res,
@@ -1118,6 +1074,9 @@ _zeitgeist_log_on_zg_proxy_acquired (GObject *source_object,
       goto cleanup;
     }
 
+  priv->connection = G_DBUS_CONNECTION (g_object_ref (
+        g_dbus_proxy_get_connection (priv->log)));
+
   version_property = g_dbus_proxy_get_cached_property (priv->log, "version");
   if (version_property)
     {
