@@ -128,6 +128,71 @@
  */
 #define ZEITGEIST_NCAL_TODO "http://www.semanticdesktop.org/ontologies/2007/04/02/ncal#Todo"
 
+/**
+ * ZEITGEIST_NCO_CONTACT:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.semanticdesktop.org/ontologies/2007/03/22/nco#Contact">http://www.semanticdesktop.org/ontologies/2007/03/22/nco&num;Contact</ulink>
+ *
+ *	A Contact. A piece of data that can provide means to identify or communicate with an entity.
+ *
+ * Children: #ZEITGEIST_NCO_PERSON_CONTACT, #ZEITGEIST_NCO_ORGANIZATION_CONTACT
+ *
+ * Parents: None
+ */
+#define ZEITGEIST_NCO_CONTACT "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#Contact"
+
+/**
+ * ZEITGEIST_NCO_CONTACT_GROUP:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.semanticdesktop.org/ontologies/2007/03/22/nco#ContactGroup">http://www.semanticdesktop.org/ontologies/2007/03/22/nco&num;ContactGroup</ulink>
+ *
+ *	A group of Contacts. Could be used to express a group in an addressbook or on a contact list of an IM application. One contact can belong to many groups.
+ *
+ * Children: None
+ *
+ * Parents: None
+ */
+#define ZEITGEIST_NCO_CONTACT_GROUP "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#ContactGroup"
+
+/**
+ * ZEITGEIST_NCO_CONTACT_LIST:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.semanticdesktop.org/ontologies/2007/03/22/nco#ContactList">http://www.semanticdesktop.org/ontologies/2007/03/22/nco&num;ContactList</ulink>
+ *
+ *	A contact list, this class represents an addressbook or a contact list of an IM application. Contacts inside a contact list can belong to contact groups.
+ *
+ * Children: None
+ *
+ * Parents: None
+ */
+#define ZEITGEIST_NCO_CONTACT_LIST "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#ContactList"
+
+/**
+ * ZEITGEIST_NCO_ORGANIZATION_CONTACT:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.semanticdesktop.org/ontologies/2007/03/22/nco#OrganizationContact">http://www.semanticdesktop.org/ontologies/2007/03/22/nco&num;OrganizationContact</ulink>
+ *
+ *	A Contact that denotes on Organization.
+ *
+ * Children: None
+ *
+ * Parents: #ZEITGEIST_NCO_CONTACT
+ */
+#define ZEITGEIST_NCO_ORGANIZATION_CONTACT "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#OrganizationContact"
+
+/**
+ * ZEITGEIST_NCO_PERSON_CONTACT:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.semanticdesktop.org/ontologies/2007/03/22/nco#PersonContact">http://www.semanticdesktop.org/ontologies/2007/03/22/nco&num;PersonContact</ulink>
+ *
+ *	A Contact that denotes a Person. A person can have multiple Affiliations.
+ *
+ * Children: None
+ *
+ * Parents: #ZEITGEIST_NCO_CONTACT
+ */
+#define ZEITGEIST_NCO_PERSON_CONTACT "http://www.semanticdesktop.org/ontologies/2007/03/22/nco#PersonContact"
+
 /**
  * ZEITGEIST_NFO_APPLICATION:
  *
@@ -161,7 +226,7 @@
  *
  *	A file containing audio content.
  *
- * Children: None
+ * Children: #ZEITGEIST_NMM_MUSIC_PIECE
  *
  * Parents: #ZEITGEIST_NFO_MEDIA
  */
@@ -250,7 +315,7 @@
  *
  * Macro defining the interpretation type <ulink url="http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#Filesystem">http://www.semanticdesktop.org/ontologies/2007/03/22/nfo&num;Filesystem</ulink>
  *
- *	A filesystem. Examples of filesystems include hard disk partitions, removable media, but also images thereof stored in files.
+ *	A filesystem. Examples of filesystems include hard disk partitions, removable media, but also images thereof stored in files such as ISO.
  *
  * Children: #ZEITGEIST_NFO_FILESYSTEM_IMAGE
  *
@@ -263,7 +328,7 @@
  *
  * Macro defining the interpretation type <ulink url="http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#FilesystemImage">http://www.semanticdesktop.org/ontologies/2007/03/22/nfo&num;FilesystemImage</ulink>
  *
- *	An image of a filesystem. Instances of this class may include CD images, DVD images or hard disk partition images created by various pieces of software (e.g. Norton Ghost).
+ *	An image of a filesystem. Instances of this class may include CD images, DVD images or hard disk partition images created by various pieces of software (e.g. Norton Ghost). Deprecated in favor of nfo:Filesystem.
  *
  * Children: None
  *
@@ -343,7 +408,7 @@
  *
  *	A piece of media content. This class may be used to express complex media containers with many streams of various media content (both aural and visual).
  *
- * Children: #ZEITGEIST_NFO_VISUAL, #ZEITGEIST_NFO_AUDIO, #ZEITGEIST_NMM_MUSIC_PIECE
+ * Children: #ZEITGEIST_NFO_VISUAL, #ZEITGEIST_NFO_AUDIO
  *
  * Parents: None
  */
@@ -592,7 +657,7 @@
  *
  * Children: None
  *
- * Parents: #ZEITGEIST_NFO_MEDIA
+ * Parents: #ZEITGEIST_NFO_AUDIO
  */
 #define ZEITGEIST_NMM_MUSIC_PIECE "http://www.semanticdesktop.org/ontologies/2009/02/19/nmm#MusicPiece"
 
@@ -687,6 +752,19 @@
  */
 #define ZEITGEIST_NMO_MIME_ENTITY "http://www.semanticdesktop.org/ontologies/2007/03/22/nmo#MimeEntity"
 
+/**
+ * ZEITGEIST_ZG_ACCEPT_EVENT:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#AcceptEvent">http://www.zeitgeist-project.com/ontologies/2010/01/27/zg&num;AcceptEvent</ulink>
+ *
+ *	Event triggered when the user accepts a request of some sort. Examples could be answering a phone call, accepting a file transfer, or accepting a friendship request over an IM protocol. See also DenyEvent for when the user denies a similar request.
+ *
+ * Children: None
+ *
+ * Parents: #ZEITGEIST_ZG_EVENT_INTERPRETATION
+ */
+#define ZEITGEIST_ZG_ACCEPT_EVENT "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#AcceptEvent"
+
 /**
  * ZEITGEIST_ZG_ACCESS_EVENT:
  *
@@ -726,6 +804,19 @@
  */
 #define ZEITGEIST_ZG_DELETE_EVENT "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#DeleteEvent"
 
+/**
+ * ZEITGEIST_ZG_DENY_EVENT:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#DenyEvent">http://www.zeitgeist-project.com/ontologies/2010/01/27/zg&num;DenyEvent</ulink>
+ *
+ *	Event triggered when the user denies a request of some sort. Examples could be rejecting a phone call, rejecting a file transfer, or denying a friendship request over an IM protocol. See also AcceptEvent for the converse event type.
+ *
+ * Children: None
+ *
+ * Parents: #ZEITGEIST_ZG_EVENT_INTERPRETATION
+ */
+#define ZEITGEIST_ZG_DENY_EVENT "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#DenyEvent"
+
 /**
  * ZEITGEIST_ZG_EVENT_INTERPRETATION:
  *
@@ -733,12 +824,25 @@
  *
  *	Base class for event interpretations. Please do no instantiate directly, but use one of the sub classes. The interpretation of an event describes 'what happened' - fx. 'something was created' or 'something was accessed'.
  *
- * Children: #ZEITGEIST_ZG_LEAVE_EVENT, #ZEITGEIST_ZG_MODIFY_EVENT, #ZEITGEIST_ZG_CREATE_EVENT, #ZEITGEIST_ZG_SEND_EVENT, #ZEITGEIST_ZG_ACCESS_EVENT, #ZEITGEIST_ZG_DELETE_EVENT, #ZEITGEIST_ZG_RECEIVE_EVENT
+ * Children: #ZEITGEIST_ZG_DENY_EVENT, #ZEITGEIST_ZG_ACCESS_EVENT, #ZEITGEIST_ZG_EXPIRE_EVENT, #ZEITGEIST_ZG_LEAVE_EVENT, #ZEITGEIST_ZG_CREATE_EVENT, #ZEITGEIST_ZG_MOVE_EVENT, #ZEITGEIST_ZG_ACCEPT_EVENT, #ZEITGEIST_ZG_SEND_EVENT, #ZEITGEIST_ZG_MODIFY_EVENT, #ZEITGEIST_ZG_DELETE_EVENT, #ZEITGEIST_ZG_RECEIVE_EVENT
  *
  * Parents: None
  */
 #define ZEITGEIST_ZG_EVENT_INTERPRETATION "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#EventInterpretation"
 
+/**
+ * ZEITGEIST_ZG_EXPIRE_EVENT:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#ExpireEvent">http://www.zeitgeist-project.com/ontologies/2010/01/27/zg&num;ExpireEvent</ulink>
+ *
+ *	Event triggered when something expires or times out. These types of events are normally not triggered by the user, but by the operating system or some external party. Examples are a recurring calendar item or task deadline that expires or a when the user fails to respond to an external request such as a phone call.
+ *
+ * Children: None
+ *
+ * Parents: #ZEITGEIST_ZG_EVENT_INTERPRETATION
+ */
+#define ZEITGEIST_ZG_EXPIRE_EVENT "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#ExpireEvent"
+
 /**
  * ZEITGEIST_ZG_LEAVE_EVENT:
  *
@@ -765,6 +869,19 @@
  */
 #define ZEITGEIST_ZG_MODIFY_EVENT "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#ModifyEvent"
 
+/**
+ * ZEITGEIST_ZG_MOVE_EVENT:
+ *
+ * Macro defining the interpretation type <ulink url="http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#MoveEvent">http://www.zeitgeist-project.com/ontologies/2010/01/27/zg&num;MoveEvent</ulink>
+ *
+ *	Event triggered when a resource has been moved from a location to another. Fx. moving a file from a folder to another.
+ *
+ * Children: None
+ *
+ * Parents: #ZEITGEIST_ZG_EVENT_INTERPRETATION
+ */
+#define ZEITGEIST_ZG_MOVE_EVENT "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#MoveEvent"
+
 /**
  * ZEITGEIST_ZG_RECEIVE_EVENT:
  *
@@ -792,7 +909,6 @@
 #define ZEITGEIST_ZG_SEND_EVENT "http://www.zeitgeist-project.com/ontologies/2010/01/27/zg#SendEvent"
 
 
-
 /* IMPORTANT: AUTO GENERATED CONTENT STOP */
 
 #endif /* _ZEITGEIST_ONTOLOGY_INTERPRETATIONS_H_ */
