@@ -92,7 +92,7 @@ zeitgeist_register_symbol (SymbolInfo *i)
  * 
  * Gets list of immediate parents of the specified symbol.
  *
- * Returns: A newly allocated list of immediate parents of this symbol. 
+ * Returns: A newly allocated list of immediate parents of this symbol.
  *          The data elements of the list contain strings which you
  *          do not own, use g_strdup() if you intend to work with them.
  *          Free the list with a call to g_list_free().
@@ -277,17 +277,14 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
-  uri = ZEITGEIST_NMO_MESSAGE;
-  parents = g_new (char*, 1);
-  parents[0] = NULL;
-  children = g_new (char*, 3);
-  children[0] = ZEITGEIST_NMO_EMAIL;
-  children[1] = ZEITGEIST_NMO_IMMESSAGE;
-  children[2] = NULL;
-  all_children = g_new (char*, 3);
-  all_children[0] = ZEITGEIST_NMO_EMAIL;
-  all_children[1] = ZEITGEIST_NMO_IMMESSAGE;
-  all_children[2] = NULL;
+  uri = ZEITGEIST_NFO_CURSOR;
+  parents = g_new (char*, 2);
+  parents[0] = ZEITGEIST_NFO_RASTER_IMAGE;
+  parents[1] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
   info = symbol_info_new (uri, parents, children, all_children);
   zeitgeist_register_symbol (info);
   g_free (parents);
@@ -379,6 +376,20 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
+  uri = ZEITGEIST_NCO_PERSON_CONTACT;
+  parents = g_new (char*, 2);
+  parents[0] = ZEITGEIST_NCO_CONTACT;
+  parents[1] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
   uri = ZEITGEIST_NCAL_CALENDAR;
   parents = g_new (char*, 1);
   parents[0] = NULL;
@@ -392,27 +403,33 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
-  uri = ZEITGEIST_NFO_BOOKMARK;
+  uri = ZEITGEIST_NCO_CONTACT;
   parents = g_new (char*, 1);
   parents[0] = NULL;
-  children = g_new (char*, 1);
-  children[0] = NULL;
-  all_children = g_new (char*, 1);
-  all_children[0] = NULL;
+  children = g_new (char*, 3);
+  children[0] = ZEITGEIST_NCO_PERSON_CONTACT;
+  children[1] = ZEITGEIST_NCO_ORGANIZATION_CONTACT;
+  children[2] = NULL;
+  all_children = g_new (char*, 3);
+  all_children[0] = ZEITGEIST_NCO_ORGANIZATION_CONTACT;
+  all_children[1] = ZEITGEIST_NCO_PERSON_CONTACT;
+  all_children[2] = NULL;
   info = symbol_info_new (uri, parents, children, all_children);
   zeitgeist_register_symbol (info);
   g_free (parents);
   g_free (children);
   g_free (all_children);
 
-  uri = ZEITGEIST_NMO_IMMESSAGE;
+  uri = ZEITGEIST_NFO_RASTER_IMAGE;
   parents = g_new (char*, 2);
-  parents[0] = ZEITGEIST_NMO_MESSAGE;
+  parents[0] = ZEITGEIST_NFO_IMAGE;
   parents[1] = NULL;
-  children = g_new (char*, 1);
-  children[0] = NULL;
-  all_children = g_new (char*, 1);
-  all_children[0] = NULL;
+  children = g_new (char*, 2);
+  children[0] = ZEITGEIST_NFO_CURSOR;
+  children[1] = NULL;
+  all_children = g_new (char*, 2);
+  all_children[0] = ZEITGEIST_NFO_CURSOR;
+  all_children[1] = NULL;
   info = symbol_info_new (uri, parents, children, all_children);
   zeitgeist_register_symbol (info);
   g_free (parents);
@@ -488,9 +505,23 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
-  uri = ZEITGEIST_NFO_CURSOR;
+  uri = ZEITGEIST_NMO_IMMESSAGE;
   parents = g_new (char*, 2);
-  parents[0] = ZEITGEIST_NFO_RASTER_IMAGE;
+  parents[0] = ZEITGEIST_NMO_MESSAGE;
+  parents[1] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
+  uri = ZEITGEIST_NFO_HTML_DOCUMENT;
+  parents = g_new (char*, 2);
+  parents[0] = ZEITGEIST_NFO_PLAIN_TEXT_DOCUMENT;
   parents[1] = NULL;
   children = g_new (char*, 1);
   children[0] = NULL;
@@ -533,9 +564,9 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
-  uri = ZEITGEIST_NFO_HTML_DOCUMENT;
+  uri = ZEITGEIST_ZG_ACCEPT_EVENT;
   parents = g_new (char*, 2);
-  parents[0] = ZEITGEIST_NFO_PLAIN_TEXT_DOCUMENT;
+  parents[0] = ZEITGEIST_ZG_EVENT_INTERPRETATION;
   parents[1] = NULL;
   children = g_new (char*, 1);
   children[0] = NULL;
@@ -547,18 +578,27 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
-  uri = ZEITGEIST_NFO_PLAIN_TEXT_DOCUMENT;
+  uri = ZEITGEIST_NFO_BOOKMARK;
+  parents = g_new (char*, 1);
+  parents[0] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
+  uri = ZEITGEIST_ZG_EXPIRE_EVENT;
   parents = g_new (char*, 2);
-  parents[0] = ZEITGEIST_NFO_TEXT_DOCUMENT;
+  parents[0] = ZEITGEIST_ZG_EVENT_INTERPRETATION;
   parents[1] = NULL;
-  children = g_new (char*, 3);
-  children[0] = ZEITGEIST_NFO_SOURCE_CODE;
-  children[1] = ZEITGEIST_NFO_HTML_DOCUMENT;
-  children[2] = NULL;
-  all_children = g_new (char*, 3);
-  all_children[0] = ZEITGEIST_NFO_SOURCE_CODE;
-  all_children[1] = ZEITGEIST_NFO_HTML_DOCUMENT;
-  all_children[2] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
   info = symbol_info_new (uri, parents, children, all_children);
   zeitgeist_register_symbol (info);
   g_free (parents);
@@ -600,22 +640,6 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
-  uri = ZEITGEIST_NFO_RASTER_IMAGE;
-  parents = g_new (char*, 2);
-  parents[0] = ZEITGEIST_NFO_IMAGE;
-  parents[1] = NULL;
-  children = g_new (char*, 2);
-  children[0] = ZEITGEIST_NFO_CURSOR;
-  children[1] = NULL;
-  all_children = g_new (char*, 2);
-  all_children[0] = ZEITGEIST_NFO_CURSOR;
-  all_children[1] = NULL;
-  info = symbol_info_new (uri, parents, children, all_children);
-  zeitgeist_register_symbol (info);
-  g_free (parents);
-  g_free (children);
-  g_free (all_children);
-
   uri = ZEITGEIST_NFO_IMAGE;
   parents = g_new (char*, 2);
   parents[0] = ZEITGEIST_NFO_VISUAL;
@@ -637,27 +661,53 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
+  uri = ZEITGEIST_NFO_PLAIN_TEXT_DOCUMENT;
+  parents = g_new (char*, 2);
+  parents[0] = ZEITGEIST_NFO_TEXT_DOCUMENT;
+  parents[1] = NULL;
+  children = g_new (char*, 3);
+  children[0] = ZEITGEIST_NFO_SOURCE_CODE;
+  children[1] = ZEITGEIST_NFO_HTML_DOCUMENT;
+  children[2] = NULL;
+  all_children = g_new (char*, 3);
+  all_children[0] = ZEITGEIST_NFO_SOURCE_CODE;
+  all_children[1] = ZEITGEIST_NFO_HTML_DOCUMENT;
+  all_children[2] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
   uri = ZEITGEIST_ZG_EVENT_INTERPRETATION;
   parents = g_new (char*, 1);
   parents[0] = NULL;
-  children = g_new (char*, 8);
-  children[0] = ZEITGEIST_ZG_LEAVE_EVENT;
-  children[1] = ZEITGEIST_ZG_MODIFY_EVENT;
-  children[2] = ZEITGEIST_ZG_CREATE_EVENT;
-  children[3] = ZEITGEIST_ZG_SEND_EVENT;
-  children[4] = ZEITGEIST_ZG_ACCESS_EVENT;
-  children[5] = ZEITGEIST_ZG_DELETE_EVENT;
-  children[6] = ZEITGEIST_ZG_RECEIVE_EVENT;
-  children[7] = NULL;
-  all_children = g_new (char*, 8);
-  all_children[0] = ZEITGEIST_ZG_LEAVE_EVENT;
+  children = g_new (char*, 12);
+  children[0] = ZEITGEIST_ZG_DENY_EVENT;
+  children[1] = ZEITGEIST_ZG_ACCESS_EVENT;
+  children[2] = ZEITGEIST_ZG_EXPIRE_EVENT;
+  children[3] = ZEITGEIST_ZG_LEAVE_EVENT;
+  children[4] = ZEITGEIST_ZG_CREATE_EVENT;
+  children[5] = ZEITGEIST_ZG_MOVE_EVENT;
+  children[6] = ZEITGEIST_ZG_ACCEPT_EVENT;
+  children[7] = ZEITGEIST_ZG_SEND_EVENT;
+  children[8] = ZEITGEIST_ZG_MODIFY_EVENT;
+  children[9] = ZEITGEIST_ZG_DELETE_EVENT;
+  children[10] = ZEITGEIST_ZG_RECEIVE_EVENT;
+  children[11] = NULL;
+  all_children = g_new (char*, 12);
+  all_children[0] = ZEITGEIST_ZG_DENY_EVENT;
   all_children[1] = ZEITGEIST_ZG_MODIFY_EVENT;
-  all_children[2] = ZEITGEIST_ZG_CREATE_EVENT;
-  all_children[3] = ZEITGEIST_ZG_SEND_EVENT;
-  all_children[4] = ZEITGEIST_ZG_ACCESS_EVENT;
-  all_children[5] = ZEITGEIST_ZG_DELETE_EVENT;
-  all_children[6] = ZEITGEIST_ZG_RECEIVE_EVENT;
-  all_children[7] = NULL;
+  all_children[2] = ZEITGEIST_ZG_EXPIRE_EVENT;
+  all_children[3] = ZEITGEIST_ZG_LEAVE_EVENT;
+  all_children[4] = ZEITGEIST_ZG_CREATE_EVENT;
+  all_children[5] = ZEITGEIST_ZG_MOVE_EVENT;
+  all_children[6] = ZEITGEIST_ZG_ACCEPT_EVENT;
+  all_children[7] = ZEITGEIST_ZG_SEND_EVENT;
+  all_children[8] = ZEITGEIST_ZG_ACCESS_EVENT;
+  all_children[9] = ZEITGEIST_ZG_DELETE_EVENT;
+  all_children[10] = ZEITGEIST_ZG_RECEIVE_EVENT;
+  all_children[11] = NULL;
   info = symbol_info_new (uri, parents, children, all_children);
   zeitgeist_register_symbol (info);
   g_free (parents);
@@ -719,7 +769,7 @@ _ensure_symbols_loaded (void)
 
   uri = ZEITGEIST_NMM_MUSIC_PIECE;
   parents = g_new (char*, 2);
-  parents[0] = ZEITGEIST_NFO_MEDIA;
+  parents[0] = ZEITGEIST_NFO_AUDIO;
   parents[1] = NULL;
   children = g_new (char*, 1);
   children[0] = NULL;
@@ -744,6 +794,20 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
+  uri = ZEITGEIST_ZG_DENY_EVENT;
+  parents = g_new (char*, 2);
+  parents[0] = ZEITGEIST_ZG_EVENT_INTERPRETATION;
+  parents[1] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
   uri = ZEITGEIST_NFO_TEXT_DOCUMENT;
   parents = g_new (char*, 2);
   parents[0] = ZEITGEIST_NFO_DOCUMENT;
@@ -819,6 +883,20 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
+  uri = ZEITGEIST_NCO_ORGANIZATION_CONTACT;
+  parents = g_new (char*, 2);
+  parents[0] = ZEITGEIST_NCO_CONTACT;
+  parents[1] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
   uri = ZEITGEIST_NMM_MUSIC_ALBUM;
   parents = g_new (char*, 2);
   parents[0] = ZEITGEIST_NFO_MEDIA_LIST;
@@ -913,6 +991,19 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
+  uri = ZEITGEIST_NCO_CONTACT_LIST;
+  parents = g_new (char*, 1);
+  parents[0] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
   uri = ZEITGEIST_NMM_TVSERIES;
   parents = g_new (char*, 1);
   parents[0] = NULL;
@@ -930,6 +1021,21 @@ _ensure_symbols_loaded (void)
   parents = g_new (char*, 2);
   parents[0] = ZEITGEIST_NFO_MEDIA;
   parents[1] = NULL;
+  children = g_new (char*, 2);
+  children[0] = ZEITGEIST_NMM_MUSIC_PIECE;
+  children[1] = NULL;
+  all_children = g_new (char*, 2);
+  all_children[0] = ZEITGEIST_NMM_MUSIC_PIECE;
+  all_children[1] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
+  uri = ZEITGEIST_NCO_CONTACT_GROUP;
+  parents = g_new (char*, 1);
+  parents[0] = NULL;
   children = g_new (char*, 1);
   children[0] = NULL;
   all_children = g_new (char*, 1);
@@ -985,6 +1091,37 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
+  uri = ZEITGEIST_NMO_MESSAGE;
+  parents = g_new (char*, 1);
+  parents[0] = NULL;
+  children = g_new (char*, 3);
+  children[0] = ZEITGEIST_NMO_EMAIL;
+  children[1] = ZEITGEIST_NMO_IMMESSAGE;
+  children[2] = NULL;
+  all_children = g_new (char*, 3);
+  all_children[0] = ZEITGEIST_NMO_EMAIL;
+  all_children[1] = ZEITGEIST_NMO_IMMESSAGE;
+  all_children[2] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
+  uri = ZEITGEIST_ZG_MOVE_EVENT;
+  parents = g_new (char*, 2);
+  parents[0] = ZEITGEIST_ZG_EVENT_INTERPRETATION;
+  parents[1] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
   uri = ZEITGEIST_NCAL_TIMEZONE;
   parents = g_new (char*, 1);
   parents[0] = NULL;
@@ -1054,11 +1191,10 @@ _ensure_symbols_loaded (void)
   uri = ZEITGEIST_NFO_MEDIA;
   parents = g_new (char*, 1);
   parents[0] = NULL;
-  children = g_new (char*, 4);
+  children = g_new (char*, 3);
   children[0] = ZEITGEIST_NFO_VISUAL;
   children[1] = ZEITGEIST_NFO_AUDIO;
-  children[2] = ZEITGEIST_NMM_MUSIC_PIECE;
-  children[3] = NULL;
+  children[2] = NULL;
   all_children = g_new (char*, 12);
   all_children[0] = ZEITGEIST_NMM_TVSHOW;
   all_children[1] = ZEITGEIST_NMM_MUSIC_PIECE;
@@ -1266,8 +1402,8 @@ _ensure_symbols_loaded (void)
   children[5] = NULL;
   all_children = g_new (char*, 6);
   all_children[0] = ZEITGEIST_ZG_USER_ACTIVITY;
-  all_children[1] = ZEITGEIST_ZG_WORLD_ACTIVITY;
-  all_children[2] = ZEITGEIST_ZG_HEURISTIC_ACTIVITY;
+  all_children[1] = ZEITGEIST_ZG_HEURISTIC_ACTIVITY;
+  all_children[2] = ZEITGEIST_ZG_WORLD_ACTIVITY;
   all_children[3] = ZEITGEIST_ZG_SCHEDULED_ACTIVITY;
   all_children[4] = ZEITGEIST_ZG_SYSTEM_NOTIFICATION;
   all_children[5] = NULL;
@@ -1303,6 +1439,32 @@ _ensure_symbols_loaded (void)
   g_free (children);
   g_free (all_children);
 
+  uri = ZEITGEIST_NCO_CONTACT_LIST_DATA_OBJECT;
+  parents = g_new (char*, 1);
+  parents[0] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
+  uri = ZEITGEIST_NFO_WEB_DATA_OBJECT;
+  parents = g_new (char*, 1);
+  parents[0] = NULL;
+  children = g_new (char*, 1);
+  children[0] = NULL;
+  all_children = g_new (char*, 1);
+  all_children[0] = NULL;
+  info = symbol_info_new (uri, parents, children, all_children);
+  zeitgeist_register_symbol (info);
+  g_free (parents);
+  g_free (children);
+  g_free (all_children);
+
   uri = ZEITGEIST_ZG_USER_ACTIVITY;
   parents = g_new (char*, 2);
   parents[0] = ZEITGEIST_ZG_EVENT_MANIFESTATION;
